==> punbb-1.3.tar.gz: punbb-1.3/lang/English/post.php <==
<?php

// Language definitions used in post.php and edit.php
$lang_post = array(

// Post validation stuff (many are similar to those in edit.php)
'No subject'			=>	'Topics must contain a subject.',
'Too long subject'		=>	'Subjects cannot be longer than 70 characters.',
'All caps subject'		=>	'Subjects cannot contain only capital letters.',
'No message'			=>	'You must enter a message.',
'Too long message'		=>	'Your post length is %s bytes. This exceeds the %s bytes limit.',
'All caps message'		=>	'Posts cannot contain only capital letters.',
'CSRF token mismatch'	=>	'Unable to confirm security token. A likely cause for this is that some time passed between when you first entered the page and when you posted the form. Clicking "Submit" again should solve the problem.',
'Invalid e-mail'		=>	'The e-mail address you entered is invalid.',

// Posting
'Compose your reply'	=>	'Compose and post your new reply',
'Compose your topic'	=>	'Compose and post your new topic',
'Compose edited reply'	=>	'Compose and post your edited reply',
'Compose edited topic'	=>	'Compose and post your edited topic',
'Guest post legend'		=>	'Required information for guests',
'Post errors'			=>	'<strong>Warning!</strong> The following errors must be corrected before your message can be posted:',
'Guest name'			=>	'Guest name',	// For guests (instead of Username)
'Guest e-mail'			=>	'Guest e-mail',
'Post redirect'			=>	'Post entered. Redirecting …',
'Post reply'			=>	'Post new reply',
'Post new topic'		=>	'Post new topic',
'Topic subject'			=>	'Topic subject',
'Write message'			=>	'Write message',
'Hide smilies'			=>	'Never show smilies as icons (images) for this post.',
'Subscribe'				=>	'Subscribe to this topic.',
'Stay subscribed'		=>	'Stay subscribed to this topic.',
'Topic review'			=>	'Topic review (newest first)',
'Flood'					=>	'At least %s seconds have to pass between posts. Please wait a while and try posting again.',
'Permalink post'		=>	'Permanent link to this post',
'Post settings'			=>	'Optional post settings',
'Preview reply'			=>	'Preview your new reply',
'Preview new topic'		=>	'Preview your new topic',
'Preview reply'			=>	'Preview reply', // For preview button
'Preview topic'			=>	'Preview topic', // For preview button
'Submit reply'			=>	'Submit reply', // For submit button
'Submit topic'			=>	'Submit topic', // For submit button
'Post byline'			=>	'<span>Post by </span>%s',
'Topic byline'			=>	'<span>Topic by </span>%s',
'Reply byline'			=>	'<span>Reply by </span>%s',
'Post posted'			=>	'<span>Posted </span>%s',




// Edit post
'Edit post legend'		=>	'Edit message',
'Edit topic'			=>	'Edit topic',
'Edit reply'			=>	'Edit reply',
'Silent edit'			=>	'Silent edit (don\'t display "Last edited by …" in topic view for this edit).',
'Preview edited topic'	=>	'Preview of your edited topic',
'Preview edited reply'	=>	'Preview of your edited reply',
'Edit redirect'			=>	'Post updated. Redirecting …'

);

==> punbb-1.4.1.tar.gz: punbb-1.4.1/lang/English/post.php <==
<?php

// Language definitions used in post.php and edit.php
$lang_post = array(

// Post validation stuff (many are similar to those in edit.php)
'No subject'			=>	'Topics must contain a subject.',
'Too long subject'		=>	'Subjects cannot be longer than 70 characters.',
'All caps subject'		=>	'Subjects cannot contain only capital letters.',
'No message'			=>	'You must enter a message.',
'Too long message'		=>	'Your post length is %s bytes. This exceeds the %s bytes limit.',
'All caps message'		=>	'Posts cannot contain only capital letters.',
'CSRF token mismatch'	=>	'Unable to confirm security token. A likely cause for this is that some time passed between when you first entered the page and when you posted the form. Clicking "Submit" again should solve the problem.',
'Invalid e-mail'		=>	'The email address you entered is invalid.',

// Posting
'Compose your reply'	=>	'Compose and post your new reply',
'Compose your topic'	=>	'Compose and post your new topic',
'Compose edited reply'	=>	'Compose and post your edited reply',
'Compose edited topic'	=>	'Compose and post your edited topic',
'Guest post legend'		=>	'Required information for guests',
'Post errors'			=>	'<strong>Warning!</strong> The following errors must be corrected before your message can be posted:',
'Guest name'			=>	'Guest name',	// For guests (instead of Username)
'Guest e-mail'			=>	'Guest email',
'Post redirect'			=>	'Post entered.',
'Post reply'			=>	'Post new reply',
'Post new topic'		=>	'Post new topic',
'Topic subject'			=>	'Topic subject',
'Write message'			=>	'Write message',
'Hide smilies'			=>	'Never show smilies as icons for this post.',
'Subscribe'				=>	'Subscribe to this topic.',
'Stay subscribed'		=>	'Stay subscribed to this topic.',
'Topic review'			=>	'Topic review (newest first)',
'Flood'					=>	'At least %s seconds have to pass between posts. Please wait a while and try posting again.',
'Permalink post'		=>	'Permanent link to this post',
'Post settings'			=>	'Optional post settings',
'Preview reply'			=>	'Preview your new reply',
'Preview new topic'		=>	'Preview your new topic',
'Preview reply'			=>	'Preview reply', // For preview button
'Preview topic'			=>	'Preview topic', // For preview button
'Submit reply'			=>	'Submit reply', // For submit button
'Submit topic'			=>	'Submit topic', // For submit button
'Post byline'			=>	'<span>Post by </span>%s',
'Topic byline'			=>	'<span>Topic by </span>%s',
'Reply byline'			=>	'<span>Reply by </span>%s',
'Post posted'			=>	'<span>Posted </span>%s',




// Edit post
'Edit post legend'		=>	'Edit message',
'Edit topic'			=>	'Edit topic',
'Edit reply'			=>	'Edit reply',
'Silent edit'			=>	'Silent edit.',
'Preview edited topic'	=>	'Preview of your edited topic',
'Preview edited reply'	=>	'Preview of your edited reply',
'Edit redirect'			=>	'Post updated.'

);
